import "core-js/modules/es.object.assign.js";
import React, { isValidElement } from 'react';
import PropTypes from 'prop-types';
import { compiler } from 'markdown-to-jsx';
import Link from 'rsg-components/Link';
import Text from 'rsg-components/Text';
import Para from 'rsg-components/Para';
import Code from 'rsg-components/Code';
import MdxBlockquote from 'rsg-components/mdx/MdxBlockquote';
import MdxCodeStatic from 'rsg-components/mdx/MdxCodeStatic';
import MdxHeading from 'rsg-components/mdx/MdxHeading';
import MdxHighlight from 'rsg-components/mdx/MdxHighlight';
import MdxHr from 'rsg-components/mdx/MdxHr';
import MdxList from 'rsg-components/mdx/MdxList';
import MdxPre from 'rsg-components/mdx/MdxPre';
import MdxTable from 'rsg-components/mdx/MdxTable';
import MdxTableBody from 'rsg-components/mdx/MdxTableBody';
import MdxTableCell from 'rsg-components/mdx/MdxTableCell';
import MdxTableHead from 'rsg-components/mdx/MdxTableHead';
import MdxTableRow from 'rsg-components/mdx/MdxTableRow'; // HACK: markdown-to-jsx doesn't destinguish between inline and block code blocks,
// so we highlight syntax in the <pre> tag and assume <code> is always inline.

var Pre = function Pre(props) {
  if ( /*#__PURE__*/isValidElement(props.children)) {
    return /*#__PURE__*/React.createElement(MdxPre, null, /*#__PURE__*/React.createElement(MdxCodeStatic, null, /*#__PURE__*/React.createElement(MdxHighlight, props.children.props)));
  }

  return /*#__PURE__*/React.createElement(MdxPre, props);
};

Pre.propTypes = {
  children: PropTypes.node
};
export var baseOverrides = {
  a: {
    component: Link
  },
  h1: {
    component: MdxHeading,
    props: {
      level: 1
    }
  },
  h2: {
    component: MdxHeading,
    props: {
      level: 2
    }
  },
  h3: {
    component: MdxHeading,
    props: {
      level: 3
    }
  },
  h4: {
    component: MdxHeading,
    props: {
      level: 4
    }
  },
  h5: {
    component: MdxHeading,
    props: {
      level: 5
    }
  },
  h6: {
    component: MdxHeading,
    props: {
      level: 6
    }
  },
  p: {
    component: Para,
    props: {
      semantic: 'p'
    }
  },
  em: {
    component: Text,
    props: {
      semantic: 'em'
    }
  },
  strong: {
    component: Text,
    props: {
      semantic: 'strong'
    }
  },
  ul: {
    component: MdxList
  },
  ol: {
    component: MdxList,
    props: {
      ordered: true
    }
  },
  blockquote: {
    component: MdxBlockquote
  },
  code: {
    component: Code
  },
  pre: {
    component: Pre
  },
  hr: {
    component: MdxHr
  },
  table: {
    component: MdxTable
  },
  thead: {
    component: MdxTableHead
  },
  th: {
    component: MdxTableCell,
    props: {
      header: true
    }
  },
  tbody: {
    component: MdxTableBody
  },
  tr: {
    component: MdxTableRow
  },
  td: {
    component: MdxTableCell
  }
};
export var inlineOverrides = Object.assign({}, baseOverrides, {
  p: {
    component: Text
  }
});
export var Markdown = function Markdown(_ref) {
  var text = _ref.text,
      inline = _ref.inline;
  var overrides = inline ? inlineOverrides : baseOverrides;
  return compiler(text, {
    overrides: overrides,
    forceBlock: true
  });
};
Markdown.propTypes = {
  text: PropTypes.string.isRequired,
  inline: PropTypes.bool
};
export default Markdown;