import "core-js/modules/es.string.replace.js";
import "core-js/modules/es.regexp.exec.js";
import find from 'lodash/find';
import getAst from './getAst'; // Strip semicolon (;) at the end

var unsemicolon = function unsemicolon(s) {
  return s.replace(/;\s*$/, '');
};
/**
 * Wraps the last top-level expression in a return statement
 * (kind of an implicit return).
 *
 * Example:
 * var a = 1; React.createElement('i', null, a); // =>
 * var a = 1; return (React.createElement('i', null, a));
 */


export default function insertReturnLastExpression(code) {
  var ast = getAst(code);

  if (!ast) {
    return code;
  }

  var lastExpressionPosition = find(ast.body.reverse(), {
    type: 'ExpressionStatement'
  });

  if (!lastExpressionPosition) {
    return code;
  }

  var start = lastExpressionPosition.start,
      end = lastExpressionPosition.end;
  var head = unsemicolon(code.substring(0, start));
  var lastExpressionCode = unsemicolon(code.substring(start, end));
  return head + ";\nreturn (" + lastExpressionCode + ");";
}