"use strict";

exports.__esModule = true;
exports.default = mdxLoader;

require("core-js/modules/es.promise.js");

var _mdx = _interopRequireDefault(require("@mdx-js/mdx"));

var _sucrase = require("sucrase");

var _loaderUtils = _interopRequireDefault(require("loader-utils"));

var _addReact = _interopRequireDefault(require("./rehype/addReact"));

var _addExampleIndicies = _interopRequireDefault(require("./rehype/addExampleIndicies"));

var _exportExamples = _interopRequireDefault(require("./rehype/exportExamples"));

var _exportStories = _interopRequireDefault(require("./rehype/exportStories"));

var _markStaticExamples = _interopRequireDefault(require("./rehype/markStaticExamples"));

var _provideCurrentComponent = _interopRequireDefault(require("./rehype/provideCurrentComponent"));

var _provideDocumentScope = _interopRequireDefault(require("./rehype/provideDocumentScope"));

var _provideExampleScope = _interopRequireDefault(require("./rehype/provideExampleScope"));

var _updateExamples = _interopRequireDefault(require("./rehype/updateExamples"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const HEADER = `
import { mdx } from '@mdx-js/react';
`;

async function mdxLoader(content) {
  const callback = this.async() || (() => '');

  const {
    updateExample,
    context
  } = this._styleguidist;
  const {
    component: componentPath
  } = _loaderUtils.default.getOptions(this) || {};
  let result;

  try {
    result = await (0, _mdx.default)(content, {
      filepath: this.resourcePath,
      rehypePlugins: [_addReact.default, _markStaticExamples.default, _addExampleIndicies.default, (0, _updateExamples.default)({
        updateExample,
        mdxDocumentPath: this.resourcePath
      }), _exportExamples.default, // Sections don't have current components
      componentPath && (0, _exportStories.default)({
        componentPath,
        mdxDocumentPath: this.resourcePath
      }), (0, _provideDocumentScope.default)({
        context
      }), _provideExampleScope.default, componentPath && (0, _provideCurrentComponent.default)({
        componentPath
      })]
    });
  } catch (err) {
    return callback(err);
  }

  const code = `${HEADER}\n${result}`; // Compile JSX to JavaScript with mdx pragma

  const compiledCode = (0, _sucrase.transform)(code, {
    transforms: ['jsx'],
    jsxPragma: 'mdx'
  }).code; // console.log('='.repeat(80));
  // console.log('🦜🦜🦜🦜🦜🦜🦜', this.resourcePath, compiledCode);

  return callback(null, compiledCode);
}