"use strict";

exports.__esModule = true;
exports.default = void 0;

var _fs = _interopRequireDefault(require("fs"));

var _path = _interopRequireDefault(require("path"));

var _qss = require("qss");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const storiesLoader = _path.default.resolve(__dirname, '../stories-loader.js'); // TODO: Use readdir() instead?


const getStoriesFile = componentPath => {
  const componentExtension = _path.default.extname(componentPath);

  const extensions = ['.stories.js', '.stories.tsx', '.stories.ts', '.stories.jsx', '.story.js', '.story.tsx', '.story.ts', '.story.jsx'];
  const names = [// `ComponentName.stories`
  componentPath.replace(componentExtension, ''), // `FolderName.stories` when component definition file is `index`
  _path.default.join(_path.default.dirname(componentPath), _path.default.basename(_path.default.dirname(componentPath)))];

  for (const name of names) {
    for (const extension of extensions) {
      const filePath = `${name}${extension}`;

      const exists = _fs.default.existsSync(filePath);

      if (exists) {
        return filePath;
      }
    }
  }

  return false;
};
/**
 * Reexport stories from a CSF file via webpack loader (to enable hot reload).
 *
 * import Button from './Button'
 * import Container from './Container'
 * export const basic = () => <Container><Button /></Container>
 *
 * ->
 *
 * import { __stories_namedExamples, __stories_storiesScope } from '!!...'
 * export const __namedExamples = __stories_namedExamples;
 * export const __storiesScope = __stories_storiesScope;
 */


var _default = ({
  componentPath,
  mdxDocumentPath
}) => () => treeRaw => {
  const tree = treeRaw;

  const componentAbsolutePath = _path.default.resolve(_path.default.dirname(mdxDocumentPath), componentPath);

  const storiesFile = getStoriesFile(componentAbsolutePath);

  if (!storiesFile) {
    return tree;
  } // Rexporting story via a webpack loader to enable hot reload on chaning
  // story code. Looks like MDX doesn't support reexports of any kind, so
  // importing and then exporting a const is the only form that works.


  const query = {
    componentPath,
    mdxDocumentPath
  };
  tree.children.push({
    type: 'import',
    value: `import { __stories_namedExamples, __stories_storiesScope } from '!!${storiesLoader}?${(0, _qss.encode)(query)}!${storiesFile}'`
  });
  tree.children.push({
    type: 'export',
    value: `export const __namedExamples = __stories_namedExamples`
  });
  tree.children.push({
    type: 'export',
    value: `export const __storiesScope = __stories_storiesScope`
  });
  return tree;
};

exports.default = _default;