"use strict";

exports.__esModule = true;
exports.default = void 0;

var _escodegen = require("escodegen");

var _toAst = _interopRequireDefault(require("to-ast"));

var _astTypes = require("ast-types");

var _getImportsMap = _interopRequireDefault(require("../utils/getImportsMap"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const getLocalName = name => `__context_import_${name}`;

const getScopeName = module => module.replace(/^__context_import_/, '');

const getImportsMapFromNodes = importNodes => (0, _getImportsMap.default)(importNodes.map(n => n.value).join('\n'));

const moduleNamesMapToModulesMap = modulesNamesMap => {
  const moduleMap = {};

  for (const module of Object.keys(modulesNamesMap)) {
    moduleMap[getScopeName(module)] = {
      toAST: () => _astTypes.builders.identifier(module)
    };
  }

  return moduleMap;
};
/**
 * 1. Add import statements for all context modules — modules provied by the
 *    user in the style guide config
 * 2. Add an export statement with a map with all imported into an Mdx document
 *    modules, and context modules:
 *
 * import Button from './Button'
 * import Input from './Input'
 *
 * ->
 *
 * ...
 * export const __documentScope = {'Button': Button, 'Input': Input}
 */


var _default = ({
  context
}) => () => treeRaw => {
  const tree = treeRaw; // Generate imports for context modules

  Object.entries(context).forEach(([name, module]) => {
    tree.children.push({
      type: 'import',
      value: `import * as ${getLocalName(name)} from '${module}'`
    });
  });
  const importNodes = tree.children.filter(n => n.type === 'import');
  const modulesNamesMap = getImportsMapFromNodes(importNodes);
  const modulesMap = moduleNamesMapToModulesMap(modulesNamesMap);
  const exportCode = `export const __documentScope = ${(0, _escodegen.generate)((0, _toAst.default)(modulesMap))}`; // Generate export

  tree.children.push({
    type: 'export',
    value: exportCode
  });
  return tree;
};

exports.default = _default;