"use strict";

exports.__esModule = true;
exports.default = void 0;

var _unistUtilVisit = _interopRequireDefault(require("unist-util-visit"));

var _escodegen = require("escodegen");

var _toAst = _interopRequireDefault(require("to-ast"));

var _astTypes = require("ast-types");

var _getImports = _interopRequireDefault(require("../utils/getImports"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const getCodeValue = node => node.children[0].type === 'text' ? String(node.children[0].value) : '';

const getLocalName = index => `__ex_import_${index}`;

const getAllImportedModules = tree => {
  const imports = [];
  (0, _unistUtilVisit.default)(tree, {
    type: 'element',
    tagName: 'code'
  }, node => {
    if (!node.properties.static) {
      const code = getCodeValue(node);
      imports.push(...(0, _getImports.default)(code));
    }
  });
  return [...new Set(imports)];
};

const getModulePathToModuleMap = modules => {
  const moduleMap = {};
  modules.forEach((module, index) => {
    moduleMap[module] = {
      toAST: () => _astTypes.builders.identifier(getLocalName(index))
    };
  });
  return moduleMap;
};
/**
 * 1. Import each module imported in any non-static example into the Mdx document,
 *    so they are bundled by webpack and available at runtime.
 * 2. Export the map of these modules that will be used in the custom `require`
 *    method during the example code execution.
 *
 * ```jsx
 * import Button from './Button'
 * ...
 * ```
 *
 * ->
 *
 * import * as __ex_import_0 from './Button'
 * export const __exampleScope = {'./Button': __ex_import_0}
 * ...
 */


var _default = () => treeRaw => {
  const tree = treeRaw;
  const modules = getAllImportedModules(tree); // Generate imports

  modules.forEach((module, index) => {
    tree.children.push({
      type: 'import',
      value: `import * as ${getLocalName(index)} from '${module}'`
    });
  }); // Generate export

  const modulesMap = getModulePathToModuleMap(modules);
  const exportCode = `export const __exampleScope = ${(0, _escodegen.generate)((0, _toAst.default)(modulesMap))}`;
  tree.children.push({
    type: 'export',
    value: exportCode
  });
  return tree;
};

exports.default = _default;