"use strict";

exports.__esModule = true;
exports.default = getAst;
exports.BABEL_OPTIONS = void 0;

var _parser = require("@babel/parser");

var _glogg = _interopRequireDefault(require("glogg"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const logger = (0, _glogg.default)('rsg');

const startsWithJsx = code => !!code.trim().match(/^</);

const wrapCodeInFragment = code => `<React.Fragment>${code}</React.Fragment>;`;

const BABEL_OPTIONS = {
  allowReturnOutsideFunction: true,
  allowAwaitOutsideFunction: true,
  errorRecovery: true,
  sourceType: 'module',
  plugins: ['jsx', // TODO: How to support flow? We can't use `flow` and `typescript` plugins together
  'typescript', // Generate AST compatible with ESTree
  // TODO: We may want to rewrite the code to use Babel AST instead
  'estree']
};
/**
 * Try to parse source code using Babel parser, return AST.
 * If failed, return undefined.
 */

exports.BABEL_OPTIONS = BABEL_OPTIONS;

function getAst(code) {
  const wrappedCode = startsWithJsx(code) ? wrapCodeInFragment(code) : code;

  try {
    return (0, _parser.parse)(wrappedCode, BABEL_OPTIONS); // TODO: @babel/types.File
  } catch (err) {
    // TODO: Remove console.log
    console.log(`Babel cannot parse code: ${err.message}\n\nCode:\n${code}`);
    logger.debug(`Babel cannot parse code: ${err.message}\n\nCode:\n${code}`);
    return undefined;
  }
}