"use strict";

exports.__esModule = true;
exports.default = getImportsMap;

var _estreeWalker = require("estree-walker");

var _getAst = _interopRequireDefault(require("./getAst"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Returns a mapping of all import statements
 */
function getImportsMap(code) {
  // Parse example source code, but ignore errors:
  // we'll deal with them on the frontend
  const ast = (0, _getAst.default)(code);

  if (!ast) {
    return {};
  }

  const imports = {};
  (0, _estreeWalker.walk)(ast, {
    enter: nodeRaw => {
      const node = nodeRaw; // import foo from 'foo'

      if (node.type === 'ImportDeclaration') {
        if (node.source) {
          node.specifiers.forEach(specifier => {
            if (specifier.local.name) {
              imports[specifier.local.name] = node.source.value;
            }
          });
        }
      }
    }
  });
  return imports;
}