"use strict";

exports.__esModule = true;
exports.default = insertReturnLastExpression;

var _find = _interopRequireDefault(require("lodash/find"));

var _getAst = _interopRequireDefault(require("./getAst"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// Strip semicolon (;) at the end
const unsemicolon = s => s.replace(/;\s*$/, '');
/**
 * Wraps the last top-level expression in a return statement
 * (kind of an implicit return).
 *
 * Example:
 * var a = 1; React.createElement('i', null, a); // =>
 * var a = 1; return (React.createElement('i', null, a));
 */


function insertReturnLastExpression(code) {
  const ast = (0, _getAst.default)(code);

  if (!ast) {
    return code;
  }

  const lastExpressionPosition = (0, _find.default)(ast.body.reverse(), {
    type: 'ExpressionStatement'
  });

  if (!lastExpressionPosition) {
    return code;
  } // @ts-expect-error: There are no types for location ;-/


  const {
    start,
    end
  } = lastExpressionPosition;
  const head = unsemicolon(code.substring(0, start));
  const lastExpressionCode = unsemicolon(code.substring(start, end));
  return `${head};\nreturn (${lastExpressionCode});`;
}